var md5 = require("./md5");
var mergeRule = require("./merge_config");
var fs = require("fs");
mergeRule = mergeRule.mergeRule;
module.exports = function(grunt) {
    var version = "BocAbroad";   // 打包版本  grunt.option("ver")
    var srcroot = "../";
    var destroot = "release/" + version;
    var compressroot = "release/" + version;
    var bakroot = "release/bak";
    var today = new Date();

    // 项目配置
    grunt.initConfig({
        // 清理
        clean: {
            // 清理目录
            dest: compressroot
        },
        //获取源码
        copy: {
            // 全量
            allUsefullFile: {
                expand: true, // 按原路径复制
                cwd: srcroot,
                src: ["Framework/**", "BocAbroad/**"],
                dest: destroot
            },
            //备份版本
            bak: {
                expand: true, // 按原路径复制
                cwd: destroot,
                src: ["*","*/**"],
                dest: bakroot + "/curversion"
            }
        },
        // 合并代码 咱无用
        concat: {
            options: {
                // 每个文件用;拼接
                separator: ';\n'
            }
        },
        "regex-replace": {
            common: {
                src: destroot + "Framework/scripts/public/common.js",
                actions: [
                    { //修改日志等级为3级
                        name: 'modify the log level to 3',
                        search: /logmod: 3,/,
                        replace: 'logmod: 1,'
                    }
                ]
            },
            appcache: {
                src: destroot + "/boc.appcache",
                actions: [
                    { //修改日志等级为3级
                        name: '修改当前版本日期，以及版本号',
                        search: /#version.*/,
                        replace: "#version " + grunt.template.today("yyyy-mm-dd HH:MM:ss") + " " + version
                    }
                ]
            },
            moduledef: {
                src: destroot + "/Framework/scripts/appconfig.js",
                actions: []
            },
            zeptoextend: {
                src: destroot + "/Framework/scripts/lib/zepto.bocextend.js",
                actions: [
                    { //修改日志等级为3级
                        name: 'modify module require',
                        search: /\[\"\.\/lib\/zepto\"\],/,
                        replace: ''
                    }
                ]
            }
            /*
            noAuthModules: {
                src: destroot + "/scripts/config/noAuthModules.js",
                actions: [
                    { //去掉debug模式(禁止通过debug模式绕过oauth)
                        name: 'delete the debug mod',
                        search: /if\(Common.urlParams && Common.urlParams.debug\)\{[^\}]*\}/,
                        replace: '//deleted debug mod'
                    }
                ]
            }*/
        },
        //压缩js
        uglify: {
            options: {
                banner: '/*! BUILD: <%= grunt.template.today("yyyy-mm-dd") %> */\n',
                compress: {
                    drop_console: true,
                    global_defs: {
                        "DEBUG": false
                    }
                }
            },
            all_js: {
                files: {
                }
            }
        },
        //压缩css
        cssmin: {
            minify: {
                expand: true,
                cwd: destroot,
                src: ['**/*.css'],
                dest: destroot,
                ext: '.css'
            },
            options: {
                noAdvanced: true
            }
        },
        //压缩html
        htmlmin: { // Task
            html: { // Target
                options: { // Target options
                    removeComments: true,
                    collapseWhitespace: true
                },
                files: {
                }
            },
            ejs: { // Target
                options: { // Target options
                    collapseWhitespace: true
                },
                files: {
                }
            }
        },
        //制作压缩包
        compress: {
            main: {
                options: {
                    archive: compressroot + "/" + version + '.tar',
                    mode: 'tar'
                },
                files: [{
                    cwd: compressroot,
                    src: ['**/*'],
                    expand: true
                }]
            }
        }
    });

    grunt.loadNpmTasks('grunt-contrib-clean');
    grunt.loadNpmTasks('grunt-contrib-copy');
    grunt.loadNpmTasks('grunt-contrib-concat');
    grunt.loadNpmTasks('grunt-contrib-uglify');
    grunt.loadNpmTasks('grunt-contrib-cssmin');
    grunt.loadNpmTasks('grunt-contrib-htmlmin');
    //grunt.loadNpmTasks('grunt-contrib-imagemin');
    grunt.loadNpmTasks('grunt-contrib-compress');
    grunt.loadNpmTasks('grunt-regex-replace');
//    grunt.loadNpmTasks('grunt-css-sprite');

    // ------------------------- 自定义任务 ------------------------
    // ------------------------- 清理、拷贝源代码至打包目录 ------------
    grunt.task.registerTask("prepare", ["clean", "copy:allUsefullFile"]);

    // ------------------------- 模块代码（js/css）合并 ------------
    var bemergedFiles = [];
    grunt.task.registerTask("concat_module", function(){
        var tasks = ["regex-replace:moduledef"], concatcfg = grunt.config("concat"), replacecfg=grunt.config("regex-replace"), moduledef = replacecfg.moduledef;
        console.log('.............debug info.................')
        for(var f in mergeRule.megers){
            console.log(JSON.stringify(f));
            var i=0;
            for(; i<mergeRule.megers[f].length; i++){
                //如果是数组，这个模块需要先合并成一个文件
                if(mergeRule.megers[f][i].src instanceof Array){
                    concatcfg[mergeRule.megers[f][i].moduleName] = {
                        src: [],
                        dest: destroot + "/" + mergeRule.baseurl + f.replace(/\/[^\/]+\.js/, "/" + mergeRule.megers[f][i].moduleName + ".js")
                    };
                    for(var j=0; j<mergeRule.megers[f][i].src.length; j++){
                        concatcfg[mergeRule.megers[f][i].moduleName].src.push(destroot + "/" + mergeRule.baseurl+mergeRule.megers[f][i].src[j]);
                        var s = mergeRule.megers[f][i].src[j];
                        if(f.indexOf(s.replace(/.*\//g, '').replace(/\.js/, '')) == -1){
                            bemergedFiles.push(destroot + "/" + mergeRule.baseurl + s);
                        } 
                    }
                }
                else if(f.indexOf(mergeRule.megers[f][i].moduleName) == -1){
                    bemergedFiles.push(destroot + "/" + mergeRule.baseurl + mergeRule.megers[f][i].src);
                }
                //修改模块映射
                var regstr = ""
                if(mergeRule.megers[f][i].config_rjs_path){
                    //修改模块映射到新的合成文件
                    regstr = '(require.config\\({[^\\)]*)(' + mergeRule.megers[f][i].moduleName + '\\:\\s*"[^"]*")([^\\)]*\\))';
                    console.log(regstr);
                    moduledef.actions.push({
                        name: '修改模块' + (mergeRule.megers[f][i].moduleName || mergeRule.megers[f][i].src) + '映射到新的合成文件',
                        search: new RegExp(regstr),
                        replace: "$1" + mergeRule.megers[f][i].moduleName + ":'" + f.replace(/.js/g, '') + "'$3"
                    });
                }else {
                    //删除原有模块映射
                    regstr = '(require.config\\({[^\\)]*)(' + mergeRule.megers[f][i].moduleName + '\\:\\s*"[^"]*"\\s*,?)([^\\)]*\\))';
                    console.log(regstr);
                    moduledef.actions.push({
                        name: '修改模块' + (mergeRule.megers[f][i].moduleName || mergeRule.megers[f][i].src) + '映射到新的合成文件',
                        search: new RegExp(regstr),
                        replace: "$1$3"
                    });
                }
                if(mergeRule.megers[f][i].re_define_header){
                    /*
                    //删除原有的模块定义
                    regstr = 'define\\(\\s*("|\')' + mergeRule.megers[f][i].moduleName + '("|\')[^\\(\\)]*(\\([^\\(\\)]*(\\([^\\(\\)]*\\)[^\\(\\)]*)*\\)[^\\(\\)]*)*\\)';
                    console.log(regstr);
                    moduledef.actions.push({
                        name: '删除模块定义' + (mergeRule.megers[f][i].moduleName || mergeRule.megers[f][i].src),
                        search: new RegExp(regstr),
                        replace: ""
                    });
                    //增加模块路径映射
                    regstr = '(require.config\\([^\\)]*paths:\\s*{)([^\\)]*\\))';
                    console.log(regstr);
                    moduledef.actions.push({
                        name: '增加模块映射' + (mergeRule.megers[f][i].moduleName || mergeRule.megers[f][i].src),
                        search: new RegExp(regstr),
                        replace: '$1' + (mergeRule.megers[f][i].moduleName || mergeRule.megers[f][i].src) + ':"' + f.replace(/.js/g, '') + '",$2'
                    });
                    */
                   regstr = '(define\\(\\s*("|\')' + mergeRule.megers[f][i].moduleName + '("|\')\\s*,\\s*\\[)(.*?)(\\])';
                   console.log(regstr);
                   moduledef.actions.push({
                        name: '修改app中模块定义' + (mergeRule.megers[f][i].moduleName || mergeRule.megers[f][i].src),
                        search: new RegExp(regstr),
                        replace: "$1'./" + f.replace(/.js/, '') + "'$5"
                    });
                }else if(mergeRule.megers[f][i].add_define_header){
                    replacecfg[mergeRule.megers[f][i].moduleName] = {
                        src: destroot + "/" + mergeRule.baseurl + f,
                        actions: [{
                            name: '添加模块定义' + (mergeRule.megers[f][i].moduleName || mergeRule.megers[f][i].src),
                            search: new RegExp('(\\b)'),
                            replace: "$1define(\"" + mergeRule.megers[f][i].moduleName + "\",[],function(){});\n"
                        }]
                    }
                    tasks.push("regex-replace:" + mergeRule.megers[f][i].moduleName);
                    console.log(JSON.stringify(replacecfg[mergeRule.megers[f][i].moduleName]));
                }
            }
            concatcfg[f] = {
                src: [],
                dest: destroot + "/" + mergeRule.baseurl + f
            };
            //将同类模块合并到同一文件
            for(i=0; i<mergeRule.megers[f].length; i++){
                var item = mergeRule.megers[f][i], pre= destroot + "/" + mergeRule.baseurl, src = "";
                // //添加模块定义头标记
                // if(item.add_define_header){
                    // var defsrc = pre + f.replace(/\/[^\/]+\.js/, "/" + mergeRule.megers[f][i].moduleName + "_st.js");
                    // grunt.file.write(
                        // defsrc,
                        // 'define("' + item.moduleName +'",[],function(){ '
                    // );
                    // concatcfg[f].src.push(defsrc);
                // }

                //要合并的模块
                src = item.src instanceof Array ?
                    f.replace(/\/[^\/]+\.js/, "/" + mergeRule.megers[f][i].moduleName + ".js") : item.src;
                concatcfg[f].src.push(pre + src);

                // //添加模块定义结束标记
                // if(item.add_define_header){
                    // var defsrcend = pre + f.replace(/\/[^\/]+\.js/, "/" + mergeRule.megers[f][i].moduleName + "_end.js");
                    // grunt.file.write(
                        // defsrcend,
                            // '});'
                    // );
                    // concatcfg[f].src.push(defsrcend);
                // }
            }
        }
        // grunt.config("concat", concatcfg);
        grunt.config("regex-replace", replacecfg);
        concatAuto(concatcfg);
        grunt.task.run(tasks);
        deleteMegeredFile(bemergedFiles);
    });
    
    function concatAuto(concatcfg){
        var separator = "";
        for(var f in concatcfg){
            var item = concatcfg[f];
            if(f == "options"){
                separator = item.separator || ";";
            }else{
                var data = "";
                for(var i=0; i<item.src.length; i++){
                    data += fs.readFileSync(item.src[i], 'utf-8').replace(/\n/g, '\r\n') + separator;
                }
                fs.writeFileSync(item.dest, data, "utf-8");
                console.log("合并文件至" + item.dest + "成功");
            }
        }
    }
    
    function deleteMegeredFile(files){
        for(var i=0; i<files.length; i++){
            console.log("delete file:" + files[i]);
            grunt.file.delete(files[i]);
        }
    }

    // ------------------------- common.js替换 ------------
    grunt.task.registerTask("replaceModuleDef", ["regex-replace:zeptoextend"]);
    grunt.task.registerTask("replace", ["regex-replace:common"]);

    // ------------------------- 更新appcache配置信息 ------------
    grunt.task.registerTask("updateappcache", function(){
        var tasks = ["regex-replace:appcache"],
            replace = grunt.config("regex-replace"), appcache = replace.appcache;
        var content = "CACHE MANIFEST\n";
        var pre = "release/actives/actives/";
        content += "#version " + grunt.template.today("yyyy-mm-dd HH:MM:ss") + " " + version + "\n";
        content += "CACHE:\n";
        grunt.file.recurse(destroot + "/js", function(file){
            var allowExt = ["js"];
            var fileExt = file.split(".");
            fileExt = fileExt[fileExt.length-1];
            if(file.indexOf("boc.appcache") != -1 || allowExt.indexOf(fileExt) == -1){
            }else{
                var oldversionfile = bakroot + "/curversion/" + file.replace(pre, "");
                if(grunt.file.exists(bakroot + "/curversion/index.html")){ //版本备份文件夹中存在版本
                    //历史版本中存在该文件
                    var filepath = file.replace(pre, "");
                    if(filepath.indexOf("lib") != -1 || filepath.indexOf("public") != -1){
                        //lib和public文件夹下所有js列入缓存清单
                        content += file.replace(pre, "") + "\n";
                    }else{
                        //其他模块js等，修改的列入清单
                        if(grunt.file.exists(oldversionfile)){
                            var str1 = md5.hex_md5(grunt.file.read(file));
                            var str2 = md5.hex_md5(grunt.file.read(oldversionfile));
                            if(str1 != str2){
                                content += file.replace(pre, "") + "\n";
                            }
                        }
                    }
                } else{
                    //不存在版本，将所有js文件列入清单
                    content += file.replace(pre, "") + "\n";
                }
            }
        });
        content += "\nNETWORK:\n*\n*.do\n";
        content += "\nFALLBACK:\n* 404.html";
        appcache.actions[0] = {
            search: /CACHE MANIFES[^{]*404.html/,
            replace: content,
            name: '完全替换新的appcache配置',
        };
        grunt.config("regex-replace", replace);
        grunt.task.run(tasks);
        
    });
    
    grunt.task.registerTask("uglifyAll", function(){
        var tasks = ["uglify:all_js", "cssmin", "htmlmin:html"],
            uglify = grunt.config("uglify"),
            htmlmin =  grunt.config("htmlmin"),
            files = [],
            ugroot = destroot;
            grunt.file.recurse(ugroot, function(file){
                files.push(file);
            });
            var nougjs = [
                "!" + ugroot + "/public/exporting.js",
                "!" + ugroot + "/public/highcharts.js",
                "!" + ugroot + "/public/highcharts.js",
                "!" + ugroot + "/lib/jquery-1.7.2.min.js",
                "!" + ugroot + "/lib/path.js",
                "!" + ugroot + "/lib/require.js"
            ];
            var js = grunt.file.match([ugroot + "/**//*.js"].concat(nougjs), files);
            var html = grunt.file.match(ugroot + "**//*.html", files);
            var ejs = grunt.file.match(ugroot + "**//*.ejs", files);
            uglify.all_js.files = {};
            for (var i = js.length - 1; i >= 0; i--) {
                if(bemergedFiles.indexOf(js[i]) == -1){
                    uglify.all_js.files[js[i]] = js[i];
                }
            }
            grunt.config("uglify", uglify);
            htmlmin.html.files = {};
            for (var i = html.length - 1; i >= 0; i--) {
                htmlmin.html.files[html[i]] = html[i];
            }
            htmlmin.ejs.files = {};
            for (var i = ejs.length - 1; i >= 0; i--) {
                htmlmin.ejs.files[ejs[i]] = ejs[i];
            }
            grunt.config("htmlmin", htmlmin);
            grunt.task.run(tasks);
    });


    // ------------------------- 压缩任务------------- ------------
    grunt.task.registerTask("buildall", function(){
        var tasks = ["uglifyAll","copy:bak","compress"];
        grunt.task.run(tasks);
    });
};